@@ -30,6 +30,7 @@
  * SUCH DAMAGE.
  */
 
+#define _DEFAULT_SOURCE
 #include <sys/param.h>
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)hash.c	8.9 (Berkeley) 6/16/94";
@@ -108,6 +109,7 @@ __hash_open (const char *file,
 {
 	HTAB *hashp;
 
+        (void) dflags;
 #ifdef __USE_INTERNAL_STAT64
         struct stat64 statbuf;
 #else
@@ -764,7 +766,7 @@ hash_seq(dbp, key, data, flag)
 	DBT *key, *data;
 	u_int flag;
 {
-	__uint32_t bucket;
+	int32_t bucket;
 	BUFHEAD *bufp;
 	HTAB *hashp;
 	__uint16_t *bp, ndx;
@@ -852,7 +854,7 @@ extern int
 __expand_table(hashp)
 	HTAB *hashp;
 {
-	__uint32_t old_bucket, new_bucket;
+	int32_t old_bucket, new_bucket;
 	int dirsize, new_segnum, spare_ndx;
 
 #ifdef HASH_STATISTICS
@@ -925,7 +927,7 @@ __call_hash(hashp, k, len)
 	char *k;
 	int len;
 {
-	int n, bucket;
+	int32_t n, bucket;
 
 	n = hashp->hash(k, len);
 	bucket = n & hashp->HIGH_MASK;
