@@ -59,6 +59,7 @@ Supporting OS subroutines required: <<close>>, <<fstat>>, <<isatty>>,
 <<lseek64>>, <<open64>>, <<read>>, <<sbrk>>, <<write>>.
 */
 
+#define _DEFAULT_SOURCE
 #include <time.h>
 #include <stdio.h>
 #include <string.h>
@@ -137,7 +138,7 @@ _freopen64_r (struct _reent *ptr,
 
   if (file != NULL)
     {
-      f = _open64_r (ptr, (char *) file, oflags, 0666);
+      f = open64 ((char *) file, oflags, 0666);
       e = __errno_r(ptr);
     }
   else
@@ -150,10 +151,10 @@ _freopen64_r (struct _reent *ptr,
        * ignores creation flags.
        */
       f = fp->_file;
-      if ((oldflags = _fcntl_r (ptr, f, F_GETFL, 0)) == -1
+      if ((oldflags = fcntl (f, F_GETFL, 0)) == -1
 	  || ! ((oldflags & O_ACCMODE) == O_RDWR
 		|| ((oldflags ^ oflags) & O_ACCMODE) == 0)
-	  || _fcntl_r (ptr, f, F_SETFL, oflags) == -1)
+	  || fcntl (f, F_SETFL, oflags) == -1)
 	f = -1;
 #else
       /* We cannot modify without fcntl support.  */
