@@ -300,5 +300,6 @@
 {62, 0,123,__LINE__, 0x42392ead, 0xfa098707, 0x403a1999, 0x99999996},	/* 1.08157e+11=f(26.1)*/
 {61, 0,123,__LINE__, 0x42613b19, 0x1e69fb1e, 0x403bcccc, 0xccccccc9},	/* 5.92048e+11=f(27.8)*/
 {60, 0,123,__LINE__, 0x42879487, 0x9e85b8ea, 0x403d7fff, 0xfffffffc},	/* 3.24084e+12=f(29.5)*/
-0,};
+{0},
+};
 void test_cosh(m)   {run_vector_1(m,cosh_vec,(char *)(cosh),"cosh","dd");   }	
