@@ -298,5 +298,6 @@
 {64, 0,123,__LINE__, 0x0229cb1a, 0x25271190, 0x403a1999, 0x99999996},	/* 3.08122e-298=f(26.1)*/
 {64, 0, 34,__LINE__, 0x00000000, 0x00000000, 0x403bcccc, 0xccccccc9},	/* 0=f(27.8)*/
 {64, 0, 34,__LINE__, 0x00000000, 0x00000000, 0x403d7fff, 0xfffffffc},	/* 0=f(29.5)*/
-0,};
+{0}
+};
 void test_erfc(m)   {run_vector_1(m,erfc_vec,(char *)(erfc),"erfc","dd");   }	
