@@ -306,5 +306,6 @@
 {64, 0,123,__LINE__, 0xfff00000, 0x00000000, 0xfff00000, 0x00000000},   /* -inf=f(-inf)*/
 {64, 0,123,__LINE__, 0x00000000, 0x00000000, 0x00000000, 0x00000000},   /* +0=f(+0)*/
 {64, 0,123,__LINE__, 0x80000000, 0x00000000, 0x80000000, 0x00000000},   /* -0=f(-0)*/
-0,};
+{0}
+};
 void test_floorf(m)   {run_vector_1(m,floorf_vec,(char *)(floorf),"floorf","ff");   }	
