@@ -300,5 +300,5 @@
 {28, 0,123,__LINE__, 0x3f9f3031, 0x2942c60e, 0x403a1999, 0x99999996},	/* 0.0304573=f(26.1)*/
 {33, 0,123,__LINE__, 0x3fc25cf8, 0xd1c20f55, 0x403bcccc, 0xccccccc9},	/* 0.143462=f(27.8)*/
 {31, 0,123,__LINE__, 0xbfb07640, 0x84343430, 0x403d7fff, 0xfffffffc},	/* -0.0643044=f(29.5)*/
-0,};
+{0},};
 void test_j1f(m)   {run_vector_1(m,j1f_vec,(char *)(j1f),"j1f","ff");   }	
