@@ -298,5 +298,5 @@
 {32, 0,123,__LINE__, 0x3fea58be, 0xe738d0e3, 0x403a1999, 0x99999996},	/* 0.823333=f(26.1)*/
 {30, 0,123,__LINE__, 0x3fdd3b56, 0x4dfe1bfd, 0x403bcccc, 0xccccccc9},	/* 0.456747=f(27.8)*/
 {33, 0,123,__LINE__, 0xbfee1ced, 0xe66aee4e, 0x403d7fff, 0xfffffffc},	/* -0.941031=f(29.5)*/
-0,};
+{0},};
 void test_sinf(m)   {run_vector_1(m,sinf_vec,(char *)(sinf),"sinf","ff");   }	
