@@ -210,5 +210,5 @@
 {30, 0,123,__LINE__, 0xbfe4959f, 0xe0000000, 0x40000000, 0x00000000, 0x3fff3333, 0x33333338},	/* -0.643265=f(2, 1.95)*/
 {30, 0,123,__LINE__, 0xbff2f1d5, 0x60000000, 0x40080000, 0x00000000, 0x3fff3333, 0x33333338},	/* -1.18404=f(3, 1.95)*/
 {30, 0,123,__LINE__, 0xc007ffe0, 0x40000000, 0x40100000, 0x00000000, 0x3fff3333, 0x33333338},	/* -2.99994=f(4, 1.95)*/
-0,};
+{0},};
 void test_ynf(m)   {run_vector_1(m,ynf_vec,(char *)(ynf),"ynf","fif");   }	
